# setup.py
from setuptools import setup, find_packages

setup(
    name="number_series",
    version="0.1",
    packages=find_packages(),
    install_requires=[],
    author="koteswarao_s",
    author_email="suraboinavenkatakoteswarao@gmail.com",
    description="A sample package",
    url="https://github.com/yourusername/mypackage",
)



def prime(n):
    c=0
    for i in range(1,n):
        if n%i==0:
            c+=1
    return c==1
def lprime(n):
    u=[]
    for i in range(1,n+1):
        c=0
        for j in range(1,i):
            if i%j==0:
                c+=1
        if c==1:
            u.append(i)
    return u



